@@ -23,7 +23,7 @@ our @FUNCTIONS = qw/extract_path_info reverse_path create_path_string/;
 our @EXPORT_OK = (@FUNCTIONS, @SVG_REGEX);
 our %EXPORT_TAGS = (all => \@FUNCTIONS, regex => \@SVG_REGEX);
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 use Carp;
 
@@ -254,7 +254,9 @@ my $flag = qr/[01]/;
 
 my $cpair = qr/($number)$comma_wsp?($number)/;
 
-my $ceaa = qr/
+# Elliptical arc arguments.
+
+my $eaa = qr/
     ($nnn)
     $comma_wsp?
     ($nnn)
@@ -268,20 +270,6 @@ my $ceaa = qr/
     $cpair
 /x;
 
-my $eaa = qr/
-    $nnn
-    $comma_wsp?
-    $nnn
-    $comma_wsp?
-    $number
-    $comma_wsp
-    $flag
-    $comma_wsp?
-    $flag
-    $comma_wsp?
-    $cpair
-/x;
-
 our $elliptical_arc = qr/([Aa]) $wsp* ((?:$eaa $comma_wsp?)* $eaa)/x;
 
 our $vertical_lineto = qr/([Vv]) $wsp* ($numbers)/x;
@@ -400,10 +388,9 @@ sub extract_path_info
     for my $curve_data (@curves) {
         my ($command, $values) = @$curve_data;
 	my $ucc = uc $command;
-#	print "$curve\n";
         my @numbers;
 	if ($ucc eq 'A') {
-	    @numbers = ($values =~ /$ceaa/g);
+	    @numbers = ($values =~ /$eaa/g);
 	}
 	else {
 	    @numbers = ($values =~ /($number)/g);
@@ -411,7 +398,6 @@ sub extract_path_info
 	# Remove leading plus signs to keep the same behaviour as
 	# before.
 	@numbers = map {s/^\+//; $_} @numbers;
-#	print "@numbers\n";
         if ($verbose) {
             printf "$me: Extracted %d numbers: %s\n", scalar (@numbers),
 	    join (" ! ", @numbers);
@@ -441,7 +427,7 @@ sub extract_path_info
                 };
             }
         }
-        elsif (uc $command eq 'S') {
+        elsif ($ucc eq 'S') {
             my $expect_numbers = 4;
             if (@numbers % $expect_numbers != 0) {
                 croak "$me: Wrong number of values for an S curve " .
@@ -462,7 +448,7 @@ sub extract_path_info
                 };
             }
         }
-        elsif (uc $command eq 'L') {
+        elsif ($ucc eq 'L') {
             my $expect_numbers = 2;
 	    # Maintain this check here, even though it's duplicated
 	    # inside build_lineto, because it's specific to the lineto
@@ -473,7 +459,7 @@ sub extract_path_info
             my $position = position_type ($command);
 	    push @path_info, build_lineto ($position, @numbers);
         }
-        elsif (uc $command eq 'Z') {
+        elsif ($ucc eq 'Z') {
             if (@numbers > 0) {
                 croak "Wrong number of values for a Z command " .
                     scalar @numbers . " in '$path'";
@@ -486,7 +472,7 @@ sub extract_path_info
 		svg_key => $command,
             }
         }
-        elsif (uc $command eq 'Q') {
+        elsif ($ucc eq 'Q') {
             my $expect_numbers = 4;
             if (@numbers % $expect_numbers != 0) {
                 croak "Wrong number of values for a Q command " .
@@ -505,7 +491,7 @@ sub extract_path_info
                 }
             }
         }
-        elsif (uc $command eq 'T') {
+        elsif ($ucc eq 'T') {
             my $expect_numbers = 2;
             if (@numbers % $expect_numbers != 0) {
                 croak "$me: Wrong number of values for an T command " .
@@ -523,7 +509,7 @@ sub extract_path_info
                 }
             }
         }
-        elsif (uc $command eq 'H') {
+        elsif ($ucc eq 'H') {
             my $position = position_type ($command);
             for (my $i = 0; $i < @numbers; $i++) {
                 push @path_info, {
@@ -535,7 +521,7 @@ sub extract_path_info
                 };
             }
         }
-        elsif (uc $command eq 'V') {
+        elsif ($ucc eq 'V') {
             my $position = position_type ($command);
             for (my $i = 0; $i < @numbers; $i++) {
                 push @path_info, {
@@ -547,7 +533,7 @@ sub extract_path_info
                 };
             }
         }
-        elsif (uc $command eq 'A') {
+        elsif ($ucc eq 'A') {
             my $position = position_type ($command);
             my $expect_numbers = 7;
 	    if (@numbers % $expect_numbers != 0) {
@@ -565,7 +551,7 @@ sub extract_path_info
                 push @path_info, \%arc;
             }
         }
-	elsif (uc $command eq 'M') {
+	elsif ($ucc eq 'M') {
             my $expect_numbers = 2;
 	    my $position = position_type ($command);
 	    if (@numbers < $expect_numbers) {
@@ -579,7 +565,7 @@ sub extract_path_info
 		type => 'moveto',
 		name => 'moveto',
 		position => $position,
-		point => [@numbers[0,1]],
+		point => [@numbers[0, 1]],
 		svg_key => $command,
 	    };
 	    # M can be followed by implicit line-to commands, so
@@ -624,6 +610,15 @@ sub extract_path_info
                     }
                 }
                 @abs_pos = @{$element->{point}};
+		# It's possible to have a z, followed by an m,
+		# followed by a z.  This occurred with
+		# https://github.com/edent/SuperTinyIcons/blob/master/images/svg/mailchimp.svg
+		# as of commit
+		# https://github.com/edent/SuperTinyIcons/commit/fd79fb48365ee14ace58e8aed5bad046e5b8136c
+		# So we should always have a valid value in
+		# @start_drawing, in case someone makes a useless
+		# "move".
+		@start_drawing = @abs_pos;
             }
             elsif ($element->{type} eq 'line-to') {
                 if ($element->{position} eq 'relative') {
